<img align="right" width="100" src="docs/disco.png">

*Like autoruns for discs.*

# discoruns 
<a href="https://github.com/korbster/discoruns-dev/actions"><img src="https://github.com/korbster/discoruns-dev/workflows/CI/badge.svg" alt="build" /></a>
<a href="https://pypi.org/project/discoruns/"><img alt="PyPI" src="https://img.shields.io/pypi/v/discoruns?color=blue"></a>

Repository for a persistence mechanisms extraction tool that is developed alongside my bachelor thesis researches.

### Installation

Discoruns requires [docker](https://docs.docker.com/get-docker/) to be installed.

The Python installation can be easily done via pip:

```bash
pip install discoruns
```

### Usage

```bash
discoruns image myimage.vmdk
```
